Search
======

.. autoclass:: qbittorrentapi.search.SearchAPIMixIn
    :members:
    :undoc-members:
    :exclude-members: search, search_installPlugin, search_uninstallPlugin, search_enablePlugin, search_updatePlugins, search_downloadTorrent
    :show-inheritance:

.. autoclass:: qbittorrentapi.search.Search
    :members:
    :undoc-members:
    :exclude-members: installPlugin, uninstallPlugin, enablePlugin, updatePlugins, downloadTorrent

.. autoclass:: qbittorrentapi.search.SearchJobDictionary
    :members:
    :undoc-members:
    :show-inheritance:

.. autoclass:: qbittorrentapi.search.SearchResultsDictionary
    :members:
    :undoc-members:
    :show-inheritance:

.. autoclass:: qbittorrentapi.search.SearchStatusesList
    :members:
    :undoc-members:
    :show-inheritance:

.. autoclass:: qbittorrentapi.search.SearchStatus
    :members:
    :undoc-members:
    :show-inheritance:

.. autoclass:: qbittorrentapi.search.SearchCategoriesList
    :members:
    :undoc-members:
    :show-inheritance:

.. autoclass:: qbittorrentapi.search.SearchCategory
    :members:
    :undoc-members:
    :show-inheritance:

.. autoclass:: qbittorrentapi.search.SearchPluginsList
    :members:
    :undoc-members:
    :show-inheritance:

.. autoclass:: qbittorrentapi.search.SearchPlugin
    :members:
    :undoc-members:
    :show-inheritance:
